@@ -14,7 +14,7 @@ no if $] >= 5.018000, warnings => qw(experimental::smartmatch);
 my $SINGLETON;
 
 has 'argv' => (
-    is              => 'rw',
+    is              => 'ro',
     isa             => 'ArrayRef[Str]',
     default         => sub {
         my @argv;
@@ -40,12 +40,13 @@ has 'hints' => (
     is              => 'rw',
     isa             => 'ArrayRef[Str]',
     default         => sub { [] },
-); # Hints for boolean flags
+); # Hints for the parser
 
 has 'elements' => (
-    is              => 'rw',
+    is              => 'ro',
     isa             => 'ArrayRef[MooseX::App::ParsedArgv::Element]',
-    lazy_build      => 1,
+    lazy            => 1,
+    builder         => '_build_elements',
     clearer         => 'reset_elements',
 );
 
@@ -98,6 +99,8 @@ sub _build_elements {
                                 raw => $element,
                             );
                             push(@elements,$options{$flag});
+                        } else {
+                            $options{$flag}->inc_occurence;
                         }
                         $lastkey = $options{$flag};
                     }
@@ -113,6 +116,8 @@ sub _build_elements {
                             raw => $element,
                         );
                         push(@elements,$options{$key});
+                    } else {
+                        $options{$key}->inc_occurence;
                     }
                     $options{$key}->add_value($value);
                 }
@@ -126,6 +131,8 @@ sub _build_elements {
                             raw => $element,
                         );
                         push(@elements,$options{$key});
+                    } else {
+                        $options{$key}->inc_occurence;
                     }
                     $lastkey = $options{$key};
                 }
@@ -137,11 +144,10 @@ sub _build_elements {
                 # Value
                 default {
                     if (defined $lastkey) {
-                        # Is boolean 
-                        # TODO handle fuzzy
+                        # No value 
                         if ($lastkey->key ~~ $self->hints) {
                             push(@elements,MooseX::App::ParsedArgv::Element->new( key => $element, type => 'parameter' ));
-                        # Not a boolean field
+                        # Has value
                         } else {
                             $lastkey->add_value($element);
                         }
@@ -243,7 +249,7 @@ a new one will be created.
 
 =head2 argv
 
-Accessor for the    inal @ARGV. 
+Accessor for the initinal @ARGV. 
 
 =head2 hints
 
