@@ -8,4 +8,4 @@ use FindBin qw();
 use lib $FindBin::Bin.'/../testlib';
 
 use Test01;
-Test01->new_with_command->run;
\ No newline at end of file
+Test01->new_with_command( global => 1 )->run;
\ No newline at end of file
