@@ -1,8 +1,8 @@
 package Test05;
 
 #use Moose;
-use MooseX::App::Simple qw(Config Env);
-app_fuzzy;
+use MooseX::App::Simple qw(Config);
+app_fuzzy 1;
 
 option 'some_option' => (
     is            => 'rw',
@@ -24,4 +24,12 @@ sub run {
     warn $self->dump;   
 }
 
-1;
\ No newline at end of file
+1;
+
+=head1 DESCRIPTION
+
+this is how we use this command
+
+=cut
+
+
