@@ -1,6 +1,6 @@
 package Test06;
 
-use MooseX::App qw(Config Env);
+use MooseX::App qw(Config);
 app_fuzzy(1);
 app_command_name {
     my @parts = split( /[_\s]+|\b|(?<![A-Z])(?=[A-Z])|(?<=[A-Z])(?=[A-Z][a-z])/, shift );
